@@ -1,10 +1,11 @@
 # '
 A_clere<-function(y=y,x=x,g=NULL,analysis="aic"){
+   require(clere)
    x=1*as.matrix(x)
    if(is.null(g)){
       g=min(5,ncol(x))#ncol(x)
    }
-   model <- fit.clere(y = as.numeric(y), x = x, g = g, plotit = FALSE, analysis=analysis)
+   model <- clere::fit.clere(y = as.numeric(y), x = x, g = g, plotit = FALSE, analysis=analysis)
    A=c(model@intercept,rowMeans(model@Bw))
    return(A)
 }
\ No newline at end of file
