@@ -4,7 +4,7 @@
 #include <iostream>
 #include <string>
 #include <math.h>
-#include <Rmath.h>
+//#include <Rmath.h>
 
 using namespace Rcpp ;
 using namespace Eigen;
@@ -128,7 +128,7 @@ SEXP rechercheZ_relax(SEXP X,SEXP Z,SEXP bic_vide_vect,SEXP methode_tirage,SEXP
   //liste candidats (couples [i,j])
     if (imet_tirage[0]==0)//methode de changement de la ligne et de la colonne
     {
-      k=int(runif(0,p)[0]);//on tire un numero aleatoire pour savoir quel est la ligne et la colonne de candidats
+      k=int(p*runif(1)[0]);//on tire un numero aleatoire pour savoir quel est la ligne et la colonne de candidats
       for(i=0;i<p;i++)
       {
         if(i!=k)//on ne veut pas avoir de 1 sur la diagonale
@@ -144,7 +144,7 @@ SEXP rechercheZ_relax(SEXP X,SEXP Z,SEXP bic_vide_vect,SEXP methode_tirage,SEXP
     }
     else if (imet_tirage[0]==-1)//seulement la colonne
     {
-      k=int(runif(0,p)[0]);
+      k=int(p*runif(1)[0]);
       for(i=0;i<p;i++)
       {
         if(i!=k)
@@ -203,8 +203,8 @@ SEXP rechercheZ_relax(SEXP X,SEXP Z,SEXP bic_vide_vect,SEXP methode_tirage,SEXP
     {
       for(i=0;i<nbcand;i++)
       {
-        rand1=int(runif(0,p)[0]);//nombres aleatoire pour avoir le numero de la ligne
-        rand2=int(runif(0,p)[0]);//nombres aleatoire pour avoir le numero de la colonne
+        rand1=int(p*runif(1)[0]);//nombres aleatoire pour avoir le numero de la ligne
+        rand2=int(p*runif(1)[0]);//nombres aleatoire pour avoir le numero de la colonne
         if (rand1==rand2)//on ne veut pas de 1 sur la diagonale
         {
           if(rand1<p-1)
@@ -452,7 +452,7 @@ SEXP rechercheZ_relax(SEXP X,SEXP Z,SEXP bic_vide_vect,SEXP methode_tirage,SEXP
         jret=list_cand(ind_stock_bool1(w-1),1);
         Zcand=newZ;
         Zcand(iret,jret)=1-Zcand(iret,jret);
-        if (Zcand(iret,jret)==1)//si on a ajouter
+        if (Zcand(iret,jret)==1)//i we have added
         {
           for(cha=0;cha<p;cha++)
           { 
